@@ -141,7 +141,37 @@ Return a list of column names.
 =cut
 
 sub columns {
-    @{$_[0]->{Columns}};
+    my($me) = @_;
+
+    @{$me->{Columns}} = do {
+        if (@{$me->{build_data}{Showing}}) {
+            map {
+                UNIVERSAL::isa($_, 'DBIx::DBO::Table') ? ($_->columns) : $me->_build_col_val_name(@$_)
+            } @{$me->{build_data}{Showing}};
+        } else {
+            map { $_->columns } @{$me->{Tables}};
+        }
+    } unless @{$me->{Columns}};
+
+    @{$me->{Columns}};
+}
+
+sub _build_col_val_name {
+    my($me, $fld, $func, $opt) = @_;
+    return $opt->{AS} if exists $opt->{AS};
+
+    my @ary = map {
+        if (not ref $_) {
+            $me->rdbh->quote($_);
+        } elsif (UNIVERSAL::isa($_, 'DBIx::DBO::Column')) {
+            $_->[1];
+        } elsif (ref $_ eq 'SCALAR') {
+            $$_;
+        }
+    } @$fld;
+    return $ary[0] unless defined $func;
+    $func =~ s/$DBIx::DBO::DBD::placeholder/shift @ary/ego;
+    return $func;
 }
 
 =head3 C<column>
@@ -190,14 +220,16 @@ sub show {
     undef $me->{build_data}{from};
     undef $me->{build_data}{show};
     undef @{$me->{build_data}{Showing}};
+    undef @{$me->{Columns}};
     for my $fld (@_) {
         if (UNIVERSAL::isa($fld, 'DBIx::DBO::Table')) {
             croak 'Invalid table to show' unless defined $me->_table_idx($fld);
             push @{$me->{build_data}{Showing}}, $fld;
+            push @{$me->{Columns}}, $fld->columns;
             next;
         }
         # If the $fld is just a scalar use it as a column name not a value
-        push @{$me->{build_data}{Showing}}, [ $me->_parse_col_val($fld, Aliases => 0) ];
+        push @{$me->{build_data}{Showing}}, [ $me->{DBO}{dbd_class}->_parse_col_val($me, $fld, Aliases => 0) ];
     }
 }
 
@@ -257,6 +289,9 @@ sub join_table {
     push @{$me->{Join_Brackets}}, [];
     undef $me->{sql};
     undef $me->{build_data}{from};
+    undef $me->{build_data}{show};
+    push @{$me->{build_data}{Showing}}, $tbl if @{$me->{build_data}{Showing} ||= []};
+    undef @{$me->{Columns}};
     return $tbl;
 }
 
@@ -275,9 +310,9 @@ sub join_on {
     my $t2 = shift;
     my $i = $me->_table_idx($t2) or croak 'Invalid table object to join onto';
 
-    my($col1, $col1_func, $col1_opt) = $me->_parse_col_val(shift);
+    my($col1, $col1_func, $col1_opt) = $me->{DBO}{dbd_class}->_parse_col_val($me, shift);
     my $op = shift;
-    my($col2, $col2_func, $col2_opt) = $me->_parse_col_val(shift);
+    my($col2, $col2_func, $col2_opt) = $me->{DBO}{dbd_class}->_parse_col_val($me, shift);
 
     # Validate the fields
     $me->_validate_where_fields(@$col1, @$col2);
@@ -375,7 +410,7 @@ sub where {
     my $me = shift;
 
     # If the $fld is just a scalar use it as a column name not a value
-    my($fld, $fld_func, $fld_opt) = $me->_parse_col_val(shift);
+    my($fld, $fld_func, $fld_opt) = $me->{DBO}{dbd_class}->_parse_col_val($me, shift);
     my $op = shift;
     my($val, $val_func, $val_opt) = $me->{DBO}{dbd_class}->_parse_val($me, shift, Check => 'Auto');
 
@@ -425,7 +460,7 @@ sub _del_where {
 
     if (@_) {
         require Data::Dumper;
-        my($fld, $fld_func, $fld_opt) = $me->_parse_col_val(shift);
+        my($fld, $fld_func, $fld_opt) = $me->{DBO}{dbd_class}->_parse_col_val($me, shift);
         # TODO: Validate the fields?
 
         return unless exists $me->{build_data}{$clause.'_Data'};
@@ -518,18 +553,6 @@ sub _add_where {
     push @{$ref}, [ $op, $fld, $fld_func, $fld_opt, $val, $val_func, $val_opt, $opt{FORCE} ];
 }
 
-sub _parse_col_val {
-    my $me = shift;
-    my $col = shift;
-    my %c = (Check => 'Column', @_);
-    unless (defined $c{Aliases}) {
-        (my $method = (caller(1))[3]) =~ s/.*:://;
-        $c{Aliases} = $me->{DBO}{dbd_class}->_alias_preference($me, $method);
-    }
-    return $me->{DBO}{dbd_class}->_parse_val($me, $col, %c) if ref $col;
-    return [ $me->{DBO}{dbd_class}->_parse_col($me, $col, $c{Aliases}) ];
-}
-
 =head3 C<open_bracket>, C<close_bracket>
 
   $query->open_bracket('OR');
@@ -593,7 +616,7 @@ sub group_by {
     undef $me->{build_data}{group};
     undef @{$me->{build_data}{GroupBy}};
     for my $col (@_) {
-        my @group = $me->_parse_col_val($col);
+        my @group = $me->{DBO}{dbd_class}->_parse_col_val($me, $col);
         push @{$me->{build_data}{GroupBy}}, \@group;
     }
 }
@@ -610,7 +633,7 @@ sub having {
     my $me = shift;
 
     # If the $fld is just a scalar use it as a column name not a value
-    my($fld, $fld_func, $fld_opt) = $me->_parse_col_val(shift);
+    my($fld, $fld_func, $fld_opt) = $me->{DBO}{dbd_class}->_parse_col_val($me, shift);
     my $op = shift;
     my($val, $val_func, $val_opt) = $me->{DBO}{dbd_class}->_parse_val($me, shift, Check => 'Auto');
 
@@ -660,7 +683,7 @@ sub order_by {
     undef $me->{build_data}{order};
     undef @{$me->{build_data}{OrderBy}};
     for my $col (@_) {
-        my @order = $me->_parse_col_val($col);
+        my @order = $me->{DBO}{dbd_class}->_parse_col_val($me, $col);
         push @{$me->{build_data}{OrderBy}}, \@order;
     }
 }
